<map version="freeplane 1.5.9">
<!--To view this file, download free mind mapping software Freeplane from http://freeplane.sourceforge.net -->
<node TEXT="Freeplane 1.2&#xa;&#x306e;&#x6a5f;&#x80fd;" FOLDED="false" ID="ID_45488473" CREATED="1455910859947" MODIFIED="1455910859947" BACKGROUND_COLOR="#00ff99" VGAP_QUANTITY="0.0 px">
<icon BUILTIN="bee"/>
<font BOLD="true"/>
<hook NAME="MapStyle">
    <properties fit_to_viewport="false;" show_icon_for_attributes="false" show_note_icons="false" show_notes_in_map="false"/>

<map_styles>
<stylenode LOCALIZED_TEXT="styles.root_node" STYLE="oval" UNIFORM_SHAPE="true" VGAP_QUANTITY="24.0 pt">
<font SIZE="24"/>
<stylenode LOCALIZED_TEXT="styles.predefined" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="default" COLOR="#000000" STYLE="fork" MAX_WIDTH="600.0 px" MIN_WIDTH="1.0 px">
<font NAME="SansSerif" SIZE="8" BOLD="false" ITALIC="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.details"/>
<stylenode LOCALIZED_TEXT="defaultstyle.attributes">
<font SIZE="9"/>
</stylenode>
<stylenode LOCALIZED_TEXT="defaultstyle.note"/>
<stylenode LOCALIZED_TEXT="defaultstyle.floating">
<edge STYLE="hide_edge"/>
<cloud COLOR="#f0f0f0" SHAPE="ROUND_RECT"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.ok">
<icon BUILTIN="button_ok"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.needs_action">
<icon BUILTIN="messagebox_warning"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.floating_node">
<cloud COLOR="#ffffff" SHAPE="ARC"/>
<edge STYLE="hide_edge"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.topic" COLOR="#18898b" STYLE="fork">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
<edge STYLE="bezier" COLOR="#808080" WIDTH="thin"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subtopic" COLOR="#cc3300" STYLE="fork">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
<edge STYLE="bezier" COLOR="#808080" WIDTH="thin"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.subsubtopic" COLOR="#669900">
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.connection" COLOR="#606060" STYLE="fork">
<font NAME="Arial" SIZE="10" BOLD="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.important" COLOR="#ff0000">
<icon BUILTIN="yes"/>
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.question">
<icon BUILTIN="help"/>
<font NAME="Aharoni" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.key" COLOR="#996600">
<icon BUILTIN="password"/>
<font NAME="Liberation Sans" SIZE="12" BOLD="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.idea">
<icon BUILTIN="idea"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.note" COLOR="#990000">
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.date" COLOR="#0033ff">
<icon BUILTIN="calendar"/>
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.website" COLOR="#006633">
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.list" COLOR="#cc6600">
<icon BUILTIN="list"/>
<font NAME="Liberation Sans" SIZE="12" BOLD="true"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.quotation" COLOR="#338800" STYLE="fork">
<font NAME="Liberation Sans" SIZE="12" BOLD="false" ITALIC="false"/>
<edge STYLE="bezier" COLOR="#808080" WIDTH="thin"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.definition" COLOR="#666600">
<font NAME="Liberation Sans" SIZE="12" BOLD="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.description" COLOR="#996600">
<font NAME="Liberation Sans" SIZE="12" BOLD="false"/>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.pending" COLOR="#b3b95c">
<font NAME="Liberation Sans" SIZE="12"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.AutomaticLayout" POSITION="right" STYLE="bubble">
<stylenode LOCALIZED_TEXT="AutomaticLayout.level.root" COLOR="#000000">
<font SIZE="20"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,1" COLOR="#0033ff">
<font SIZE="18"/>
<edge WIDTH="8"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,2" COLOR="#00b439">
<font SIZE="16"/>
<edge STYLE="bezier" WIDTH="thin"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,3" COLOR="#990000">
<font SIZE="14"/>
</stylenode>
<stylenode LOCALIZED_TEXT="AutomaticLayout.level,4" COLOR="#111111">
<font SIZE="12"/>
</stylenode>
</stylenode>
<stylenode LOCALIZED_TEXT="styles.user-defined" POSITION="right" STYLE="bubble">
<stylenode TEXT="Reference">
<icon BUILTIN="help"/>
<edge STYLE="hide_edge"/>
<font BOLD="true"/>
<cloud COLOR="#99ffff" SHAPE="ROUND_RECT"/>
</stylenode>
<stylenode TEXT="Note" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<edge STYLE="hide_edge"/>
</stylenode>
</stylenode>
</stylenode>
</map_styles>
</hook>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12420;<b>&#12510;&#12491;&#12517;&#12450;&#12523;</b>&#12408;&#12398;&#12522;&#12531;&#12463;&#12434;&#34920;&#31034;&#12373;&#12379;&#12427;&#12395;&#12399;&#12289;&#12381;&#12428;&#12382;&#12428;&#12398;&#12486;&#12461;&#12473;&#12488;&#19978;&#12391;&#12459;&#12540;&#12477;&#12523;&#12434;&#12507;&#12496;&#12540;&#12522;&#12531;&#12464;&#65339;&#12459;&#12540;&#12477;&#12523;&#12434;&#32622;&#12356;&#12383;&#29366;&#24907;&#12391;&#12375;&#12400;&#12425;&#12367;&#24453;&#12388;&#12371;&#12392;&#65341;&#12373;&#12379;&#12390;&#12367;&#12384;&#12373;&#12356;&#12290;
    </p>
    <p>
      
    </p>
    <p>
      <b>&#12494;&#12540;&#12488;</b>
    </p>
    <ul>
      <li>
        &#12371;&#12398;&#12486;&#12461;&#12473;&#12488;&#12399;<b>&#12494;&#12540;&#12488;&#12486;&#12461;&#12473;&#12488;</b>&#12391;&#12377;&#12290;
      </li>
      <li>
        <b>&#12494;&#12540;&#12488;&#12497;&#12493;&#12523;</b>&#12398;&#34920;&#31034;&#65295;&#38750;&#34920;&#31034;&#12398;&#20999;&#12426;&#26367;&#12360;&#12399;&#12289;<i>&#12300;&#34920;&#31034; &gt; &#12494;&#12540;&#12488; &gt; &#12494;&#12540;&#12488;&#12497;&#12493;&#12523;&#12434;&#34920;&#31034;&#12301;</i>&#12434;&#23455;&#34892;&#12290;
      </li>
    </ul>
  </body>
</html>
</richcontent>
<node POSITION="left" ID="ID_1556354626" CREATED="1455910859951" MODIFIED="1455910859951" HGAP_QUANTITY="1.0 px" VSHIFT_QUANTITY="-32.0 px" BACKGROUND_COLOR="#ffff00" NUMBERED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12494;&#12540;&#12489;&#12467;&#12450;&#12398;&#27231;&#33021;</b>
    </p>
  </body>
</html>

</richcontent>
<font BOLD="false"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt;&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;&#65306;</i>&#160;<a href="freeplaneTutorial_ja.mm#ID_1337127972">&#22522;&#26412;&#12510;&#12483;&#12503;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;&#65306;</i>&#160;<a href="freeplane_ja.mm#ID_1154882439">&#32232;&#38598;&#160; &gt; &#12494;&#12540;&#12489;&#12467;&#12450;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="sharp_bezier" COLOR="#000099" WIDTH="2"/>
<node ID="ID_1266354824" CREATED="1455910859951" MODIFIED="1455910859951" STYLE="fork" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p style="text-align: left">
      &#160;<a href="http://www.freeplane.org">&#12452;&#12531;&#12521;&#12452;&#12531;</a>&#160;&#12495;&#12452;&#12497;&#12540;&#12522;&#12531;&#12463;&#27231;&#33021;&#20184;&#12365;(&#35079;&#25968;&#21487;)&#12486;&#12461;&#12473;&#12488;&#12289;&#21450;&#12403;
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt;&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_265318117">&#32232;&#38598;&gt; &#12494;&#12540;&#12489;&#12467;&#12450;&#12486;&#12461;&#12473;&#12488;</a>&#160;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;&#12513;&#12491;&#12517;&#12540;&#160;&#160;<a href="freeplane_ja.mm#ID_1162372089">&#32232;&#38598;&#160;&gt; &#12494;&#12540;&#12489;&#12467;&#12450;&#38306;&#36899;&#160;&gt;&#12486;&#12461;&#12473;&#12488;...</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal" WIDTH="thin"/>
</node>
<node ID="ID_1519332680" CREATED="1455910859952" MODIFIED="1455910859952" LINK="#ID_784697063" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-2.0 px" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#30690;&#21360;&#22411;&#12522;&#12531;&#12463;-&#21516;&#19968;&#12510;&#12483;&#12503;&#20869;&#21521;&#12369;&#65288;&#65297;&#12388;&#65289;&#12289;&#21448;&#12399;<br/>
    </p>
  </body>
</html>

</richcontent>
<edge STYLE="horizontal" WIDTH="thin"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_1830541497">&#32209;&#12398;&#30690;&#21360;&#22411;&#12522;&#12531;&#12463;</a>&#160;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;&#160;<i>&#12513;&#12491;&#12517;&#12540;</i>&#160;<a href="freeplane_ja.mm#ID_271903009">&#32232;&#38598; &gt;&#12522;&#12531;&#12463;&#160;&gt; &#12525;&#12540;&#12459;&#12523;&#12522;&#12531;&#12463;&#12434;&#20184;&#21152;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="&#x77e2;&#x5370;&#x578b;&#x30ea;&#x30f3;&#x30af;-&#x5916;&#x90e8;&#x30aa;&#x30d6;&#x30b8;&#x30a7;&#x30af;&#x30c8;&#x5411;&#x3051;&#xff08;&#xff11;&#x3064;&#xff09;&#x3001;&#x53ca;&#x3073;" ID="ID_1537075496" CREATED="1455910859952" MODIFIED="1455910859952" LINK="http://kioo.nl/" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-3.0 px" TEXT_SHORTENED="true">
<edge STYLE="horizontal" WIDTH="thin"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_1830541497">&#36196;&#12398;&#30690;&#21360;&#22411;&#12522;&#12531;&#12463;</a>&#160;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;&#160;&#12513;&#12491;&#12517;&#12540;<i>&#160; </i>&#160;<a href="freeplane_ja.mm#ID_178833757">&#32232;&#38598;&#160;&gt; &#12522;&#12531;&#12463;&#160;&gt; &#12495;&#12452;&#12497;&#12540;&#12522;&#12531;&#12463;&#12434;&#20184;&#21152;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="&#x30a2;&#x30a4;&#x30b3;&#x30f3;&#xff08;&#x8907;&#x6570;&#x53ef;&#xff09;" ID="ID_233656995" CREATED="1455910859952" MODIFIED="1455910859952" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="-7.0 px" TEXT_SHORTENED="true">
<icon BUILTIN="bookmark"/>
<icon BUILTIN="button_ok"/>
<icon BUILTIN="closed"/>
<edge STYLE="horizontal" WIDTH="thin"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_715025500">&#12450;&#12452;&#12467;&#12531;</a>&#160;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<i>&#160;&#12513;&#12491;&#12517;&#12540;</i>&#160;&#160;<a href="freeplane_ja.mm#ID_835126969">&#32232;&#38598;&#160;&gt; &#12494;&#12540;&#12489;&#12467;&#12450;&#38306;&#36899;&#160;&gt; &#12450;&#12452;&#12467;&#12531;...</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node ID="ID_300419503" CREATED="1455910859952" MODIFIED="1455910859952" HGAP_QUANTITY="296.0 px" VSHIFT_QUANTITY="-3.0 px" STYLE="bubble"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <img src="Images/doc/freeplaneApplications.png"/>
  </body>
</html>

</richcontent>
<hook NAME="FreeNode"/>
<edge STYLE="hide_edge"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160; <a href="http://freeplaneTutorial_ja.mm#ID_1795262306">&#30011;&#20687;&#65288;&#12494;&#12540;&#12489;&#12467;&#12450;&#65289;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="http://freeplane_ja.mm#ID_1277752024">&#32232;&#38598;&gt; &#12494;&#12540;&#12489;&#12467;&#12450;&#38306;&#36899;&#160;&gt; &#30011;&#20687;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="&#x9032;&#x6357;&#x5ea6;&#x8868;&#x793a; %" ID="ID_1826346574" CREATED="1455910859953" MODIFIED="1455910859953" TEXT_SHORTENED="true">
<icon BUILTIN="25%"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_707469329">&#36914;&#25431;&#24230;</a>&#160;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<i>&#160;&#12513;&#12491;&#12517;&#12540;</i>&#160;&#160;<a href="freeplane_ja.mm#ID_1053622072">&#32232;&#38598;&#160;&gt; &#12494;&#12540;&#12489;&#12467;&#12450;&#38306;&#36899;&#160;&gt; &#36914;&#25431;&#24230;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal" WIDTH="thin"/>
</node>
<node TEXT="&#x81ea;&#x52d5;&#x632f;&#x308a;&#x4ed8;&#x3051;&#x30ce;&#x30fc;&#x30c9;&#x756a;&#x53f7;" ID="ID_1097461051" CREATED="1455910859953" MODIFIED="1455910859953" NUMBERED="true" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_1531819965">&#12494;&#12540;&#12489;&#12408;&#12398;&#33258;&#21205;&#30058;&#21495;&#25391;&#12426;</a>&#160;
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal" WIDTH="thin"/>
</node>
<node TEXT="&#x30ce;&#x30fc;&#x30c9;&#x306e;&#x8868;&#x793a;&#x5e45;" ID="ID_713840726" CREATED="1455910859953" MODIFIED="1455910859953" TEXT_SHORTENED="true">
<edge STYLE="horizontal" WIDTH="thin"/>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i><a href="freeplaneTutorial_ja.mm#ID_15604512">&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</a></i>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
</node>
<node TEXT="&#x30d5;&#x30ea;&#x30fc;&#x30dd;&#x30b8;&#x30b7;&#x30e7;&#x30f3;&#x30ce;&#x30fc;&#x30c9;" FOLDED="true" POSITION="left" ID="ID_1280208201" CREATED="1455910859954" MODIFIED="1455910859954" HGAP_QUANTITY="140.0 px" VSHIFT_QUANTITY="19.0 px" TEXT_SHORTENED="true">
<hook NAME="FreeNode"/>
<font BOLD="true"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_128387683">&#12501;&#12522;&#12540;&#65288;&#12501;&#12525;&#12540;&#12486;&#12451;&#12531;&#12464;&#65289;&#12494;&#12540;&#12489;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplane_ja.mm#ID_572207726">&#32232;&#38598;&#160;&gt; &#12501;&#12522;&#12540;&#12509;&#12472;&#12471;&#12519;&#12531;&#12494;&#12540;&#12489;&#12395;&#25351;&#23450;&#65295;&#35299;&#38500;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#29366;&#24907;
    </p>
  </body>
</html>
</richcontent>
<node TEXT="&#x30d5;&#x30ed;&#x30fc;&#x30c6;&#x30a3;&#x30f3;&#x30b0;&#x30ce;&#x30fc;&#x30c9;" LOCALIZED_STYLE_REF="defaultstyle.floating" ID="ID_231217112" CREATED="1455910859954" MODIFIED="1455910859954" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true">
<font BOLD="true"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_128387683">&#12501;&#12522;&#12540;(&#12501;&#12525;&#12540;&#12486;&#12451;&#12531;&#12464;)&#12494;&#12540;&#12489;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;&#12513;&#12491;&#12517;&#12540;&#160;<a href="freeplane_ja.mm#ID_114978489">&#26360;&#24335;t&#160;&gt; &#12473;&#12479;&#12452;&#12523;&#12434;&#36969;&#29992;&#160;&gt; &#12501;&#12525;&#12540;&#12486;&#12451;&#12531;&#12464;&#12494;&#12540;&#12489;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#27161;&#28310;&#12473;&#12479;&#12452;&#12523;
    </p>
  </body>
</html>
</richcontent>
</node>
</node>
<node TEXT="&#x30d5;&#x30ea;&#x30fc; &#xff0b; &#x30d5;&#x30ed;&#x30fc;&#x30c6;&#x30a3;&#x30f3;&#x30b0; &#x30ce;&#x30fc;&#x30c9;" LOCALIZED_STYLE_REF="defaultstyle.floating" POSITION="left" ID="ID_188185624" CREATED="1455910859954" MODIFIED="1455910859954" HGAP_QUANTITY="427.0 px" VSHIFT_QUANTITY="63.0 px" TEXT_SHORTENED="true">
<hook NAME="FreeNode"/>
<font BOLD="true"/>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#65288;&#31354;&#30333;&#37096;&#20998;&#12391;&#12480;&#12502;&#12523;&#12463;&#12522;&#12483;&#12463;&#12375;&#12390;&#20316;&#25104;&#65289;
    </p>
  </body>
</html>
</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_128387683">&#12501;&#12522;&#12540;(&#12501;&#12525;&#12540;&#12486;&#12451;&#12531;&#12464;)&#12494;&#12540;&#12489;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplane_ja.mm#ID_572207726">&#32232;&#38598;&#160;&gt; &#12501;&#12522;&#12540;&#12509;&#12472;&#12471;&#12519;&#12531;&#12494;&#12540;&#12489;&#12395;&#25351;&#23450;&#65295;&#35299;&#38500;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node POSITION="right" ID="ID_1077719150" CREATED="1455910859955" MODIFIED="1455910859955" VGAP_QUANTITY="0.0 px" HGAP_QUANTITY="-10.0 px" BACKGROUND_COLOR="#ffff00" NUMBERED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12494;&#12540;&#12489;&#25313;&#24373;&#24773;&#22577; </b>
    </p>
    <p>
      &#12288;(&#12494;&#12540;&#12489;&#12467;&#12450;&#12398;&#19979;)
    </p>
    <p>
      <b>&#12288;&#12398;&#27231;&#33021;</b>
    </p>
  </body>
</html>

</richcontent>
<font BOLD="false"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b><i>&#21442;&#12288;&#29031;</i></b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_143196514">&#12494;&#12540;&#12489;&#25313;&#24373;&#24773;&#22577;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplane_ja.mm#ID_1400990107">&#32232;&#38598;&#160;&#160;&gt; &#12494;&#12540;&#12489;&#25313;&#24373;&#24773;&#22577;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="sharp_bezier" COLOR="#cc0000" WIDTH="2"/>
<node TEXT="&#x7dda;&#xff08;&#x30a8;&#x30c3;&#x30b8;&#xff09;" STYLE_REF="Reference" ID="ID_1944496966" CREATED="1455910859955" MODIFIED="1455910859955" HGAP_QUANTITY="-60.0 px" VSHIFT_QUANTITY="-111.0 px">
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="-75;115;" ENDINCLINATION="-75;115;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="102;73;" ENDINCLINATION="102;73;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1944496966" STARTINCLINATION="-174;45;" ENDINCLINATION="-174;45;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; <b>&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i>&#65306;<b><a href="freeplaneTutorial_ja.mm#ID_1812601804">P&#12503;&#12525;&#12497;&#12486;&#12451;&#12497;&#12493;&#12523;</a>&#12289;</b><a href="freeplanefreeplane_ja.mm#ID_1492225657">&#32218;&#65288;&#12456;&#12483;&#12472;&#65289;</a>&#160;&#21450;&#12403;<a href="freeplaneTutorial_ja.mm#ID_1005719714">A&#32218;&#12398;&#33394;&#12434;&#33258;&#21205;&#36984;&#25246;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b><i>&#160;</i>&#12513;&#12491;&#12517;&#12540;</b><i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_881523974">&#26360;&#24335;t &gt; &#32218;&#12398;&#24418;&#29366;&#65295;&#22826;&#12373;&#65295;&#33394;&#65307;&#32218;&#12398;&#33394;&#12434;&#33258;&#21205;&#36984;&#25246;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<node TEXT="&#x7dda;&#x306e;&#x66f8;&#x5f0f;" ID="ID_1601648824" CREATED="1455910859974" MODIFIED="1455910859974" HGAP_QUANTITY="26.0 px" VSHIFT_QUANTITY="-152.0 px">
<edge STYLE="bezier"/>
<node TEXT="&#x7dda;&#x306e;&#x592a;&#x3055;" ID="ID_241458321" CREATED="1455910859974" MODIFIED="1455910859974" VSHIFT_QUANTITY="7.0 px">
<node TEXT="&#x7d30;&#x3044;" ID="ID_1693976270" CREATED="1455910859978" MODIFIED="1455910859978" HGAP_QUANTITY="42.0 px"/>
<node TEXT="&#xff13;&#x30dd;&#x30a4;&#x30f3;&#x30c8;" ID="ID_1152182019" CREATED="1455910859978" MODIFIED="1455910859978" HGAP_QUANTITY="42.0 px" VSHIFT_QUANTITY="9.0 px">
<edge WIDTH="2"/>
</node>
<node TEXT="&#xff18;&#x30dd;&#x30a4;&#x30f3;&#x30c8;" ID="ID_1828139471" CREATED="1455910859979" MODIFIED="1455910859979" HGAP_QUANTITY="42.0 px" VSHIFT_QUANTITY="5.0 px">
<edge WIDTH="8"/>
</node>
</node>
<node TEXT="&#x7dda;&#x306e;&#x5f62;&#x72b6;" ID="ID_784697063" CREATED="1455910859979" MODIFIED="1455910859979" HGAP_QUANTITY="21.0 px" VSHIFT_QUANTITY="1.0 px">
<node TEXT="&#x76f4;&#x7dda;" ID="ID_884692926" CREATED="1455910859979" MODIFIED="1455910859979" HGAP_QUANTITY="53.0 px" VSHIFT_QUANTITY="-1.0 px">
<edge STYLE="linear" WIDTH="4"/>
</node>
<node TEXT="&#x66f2;&#x7dda;" ID="ID_609820168" CREATED="1455910859981" MODIFIED="1455910859981" HGAP_QUANTITY="57.0 px" VSHIFT_QUANTITY="9.0 px">
<edge STYLE="bezier" WIDTH="4"/>
</node>
<node TEXT="&#x5148;&#x7d30;&#x76f4;&#x7dda;" ID="ID_1647821228" CREATED="1455910859981" MODIFIED="1455910859981" HGAP_QUANTITY="60.0 px" VSHIFT_QUANTITY="10.0 px">
<edge STYLE="sharp_linear" WIDTH="4"/>
</node>
<node TEXT="&#x5148;&#x7d30;&#x66f2;&#x7dda;" ID="ID_895403951" CREATED="1455910859981" MODIFIED="1455910859981" HGAP_QUANTITY="70.0 px" VSHIFT_QUANTITY="15.0 px">
<edge STYLE="sharp_bezier" WIDTH="4"/>
</node>
<node TEXT="&#x7dda;&#x3092;&#x96a0;&#x3059;" ID="ID_1675552701" CREATED="1455910859981" MODIFIED="1455910859981" HGAP_QUANTITY="77.0 px" VSHIFT_QUANTITY="18.0 px" BACKGROUND_COLOR="#00ffff">
<edge STYLE="hide_edge" WIDTH="4"/>
</node>
</node>
<node TEXT="&#x7dda;&#x306e;&#x8272;" ID="ID_939577724" CREATED="1455910859982" MODIFIED="1455910859982">
<edge COLOR="#ff0066"/>
</node>
</node>
</node>
<node TEXT="&#x3053;&#x306e;&#x30ce;&#x30fc;&#x30c9;&#x30b3;&#x30a2;&#x306e;&#x4e0b;&#x65b9;&#x3092;&#x53c2;&#x7167;&#xff1a;" ID="ID_1010722858" CREATED="1455910859983" MODIFIED="1455910859983" STYLE="bubble" VGAP_QUANTITY="0.0 px" HGAP_QUANTITY="16.0 px" VSHIFT_QUANTITY="-1.0 px">
<font ITALIC="false"/>
<attribute NAME="a1" VALUE="value1"/>
<attribute NAME="a2" VALUE="value2"/>
<hook EQUATION="\begin{array}{l}&#xa;\mbox{I}^\fgcolor{ff0000}{\heartsuit}\mbox{\JLaTeXMath}\\&#xa;\end{array}" NAME="plugins/latex/LatexNodeHook.properties"/>
<edge STYLE="bezier" WIDTH="thin"/>
<hook URI="Images/doc/freeplaneApplications.png" SIZE="0.4148148" NAME="ExternalObject"/>
<richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <a href="http://www.freeplane.org">&#12452;&#12531;&#12521;&#12452;&#12531;</a>&#160;&#12495;&#12452;&#12497;&#12540;&#12522;&#12531;&#12463;
    </p>
    <p>
      &#27231;&#33021;&#20184;&#12365;(&#35079;&#25968;&#21487;)<b>&#12486;&#12461;&#12473;&#12488;</b>
    </p>
  </body>
</html>
</richcontent>
<node STYLE_REF="Reference" ID="ID_965583686" CREATED="1455910859992" MODIFIED="1455910859992" HGAP_QUANTITY="238.0 px" VSHIFT_QUANTITY="-1.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12494;&#12540;&#12489;&#12398;&#35443;&#32048;</b>&#160;(&#12486;&#12461;&#12473;&#12488;)
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_965583686" STARTINCLINATION="-105;17;" ENDINCLINATION="-105;17;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; <b>&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i><b>&#65306;</b>&#160;<a href="freeplaneTutorial_ja.mm#ID_898889730">&#12494;&#12540;&#12489;&#12398;&#35443;&#32048;&#12398;&#12486;&#12461;&#12473;&#12488;&#32232;&#38598;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b><i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_742575187">&#32232;&#38598;&#160;&gt; &#12494;&#12540;&#12489;&#25313;&#24373;&#24773;&#22577;&#160;&gt;&#12494;&#12540;&#12489;&#12398;&#35443;&#32048;&#12434;&#12452;&#12531;&#12521;&#12452;&#12531;&#65295;&#12480;&#12452;&#12450;&#12525;&#12464;&#32232;&#38598;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<font BOLD="false"/>
</node>
<node ID="ID_242844262" CREATED="1455910859992" MODIFIED="1455910859992" HGAP_QUANTITY="350.0 px" VSHIFT_QUANTITY="49.0 px" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <i>&#38750;&#34920;&#31034;&#12395; </i>
    </p>
    <p>
      <i>&#12391;&#12365;&#12414;&#12377;&#12290;</i>
    </p>
    <p>
      <i>(&#12484;&#12540;&#12523;&#12481;&#12483;&#12503;)</i>
    </p>
  </body>
</html>

</richcontent>
<hook NAME="FreeNode"/>
<edge STYLE="hide_edge"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_288274844">&#12484;&#12540;&#12523;&#12481;&#12483;&#12503;&#34920;&#31034;&#65288;&#12507;&#12496;&#12540;&#12486;&#12461;&#12473;&#12488;)</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplane_ja.mm#ID_180063018">&#34920;&#31034;&#160;&gt; &#12494;&#12540;&#12489;&#12434;&#30701;&#32302;&#34920;&#31034;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplane_ja.mm#ID_152459666">&#34920;&#31034;&#160;&gt; &#12484;&#12540;&#12523;&#12481;&#12483;&#12503;&#160;&gt; &#12484;&#12540;&#12523;&#12481;&#12483;&#12503;&#12434;&#34920;&#31034;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="&#x5c5e;&#x3000;&#x6027;" STYLE_REF="Reference" ID="ID_1546010515" CREATED="1455910859992" MODIFIED="1455910859992" HGAP_QUANTITY="240.0 px" VSHIFT_QUANTITY="67.0 px">
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1546010515" STARTINCLINATION="-84;-9;" ENDINCLINATION="-84;-9;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<hook NAME="FreeNode"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; <b>&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i><b>&#65306;</b>&#160;<a href="freeplaneTutorial_ja.mm#ID_1324773677">&#12494;&#12540;&#12489;&#25313;&#24373;&#24773;&#22577;&#12398;&#23646;&#24615;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b><i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_147715298">&#32232;&#38598;&#160;&gt; &#23646;&#24615;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b><i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_353026241">&#34920;&#31034;&gt;&#160;&#160;&#23646;&#24615;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node STYLE_REF="Reference" ID="ID_1064212525" CREATED="1455910859993" MODIFIED="1455910859993" HGAP_QUANTITY="244.0 px" VSHIFT_QUANTITY="127.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#31185;&#23398;<b>&#31639;&#24335;</b>
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1064212525" STARTINCLINATION="-117;-24;" ENDINCLINATION="-117;-24;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; <b>&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i><b>&#65306;</b>&#160;<a href="freeplaneTutorial_ja.mm#ID_616494746">&#31185;&#23398;&#31639;&#24335;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;&#65306;</i><b>&#12513;&#12491;&#12517;&#12540;</b><i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_1750517188">&#32232;&#38598;&#160;&gt; &#12494;&#12540;&#12489;&#25313;&#24373;&#24773;&#22577;&#160;&gt; LaTeX &#25968;&#24335;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<font BOLD="false"/>
</node>
<node STYLE_REF="Reference" ID="ID_1639134686" CREATED="1455910859993" MODIFIED="1455910859993" HGAP_QUANTITY="40.0 px" VSHIFT_QUANTITY="90.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#25313;&#22823;&#65295;&#32302;&#23567;&#21487;&#33021;&#12394;<b>&#30011;&#20687;</b>&#160;(&#21336;&#19968;)
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1639134686" STARTINCLINATION="-134;-34;" ENDINCLINATION="-134;-34;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<font BOLD="false"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; <b>&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</b></i><b>&#65306;</b>&#160;<a href="freeplaneTutorial_ja.mm#ID_575269438">&#30011;&#12288; &#160;&#20687;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b><i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_1620391394">&#32232;&#38598;&#160;&gt; &#12494;&#12540;&#12489;&#25313;&#24373;&#24773;&#22577;&#160;&gt; &#30011;&#20687;?</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node ID="ID_1802101455" CREATED="1455910859993" MODIFIED="1455910859993" HGAP_QUANTITY="142.0 px" VSHIFT_QUANTITY="220.0 px" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <i>&#12469;&#12452;&#12474;&#22793;&#26356;&#12399;&#12289;&#12371;&#12371; </i>
    </p>
    <p>
      <i>&#12434;&#12489;&#12521;&#12483;&#12464;&#12375;&#12414;&#12377;&#12290;</i>
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1802101455" STARTINCLINATION="-68;-42;" ENDINCLINATION="-68;-42;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<edge STYLE="hide_edge"/>
<hook NAME="FreeNode"/>
</node>
</node>
</node>
<node POSITION="right" ID="ID_1125102706" CREATED="1455910859993" MODIFIED="1455910859993" BACKGROUND_COLOR="#ffff00" NUMBERED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12494;&#12540;&#12488;</b>(&#25313;&#24373;&#24773;&#22577;&#12398;&#19979;&#26041;&#12289;&#21448;&#12399;
    </p>
    <p>
      &#29420;&#31435;&#12454;&#12451;&#12531;&#12489;&#12454;&#34920;&#31034;)<b>&#12398;&#27231;&#33021;</b>
    </p>
  </body>
</html>

</richcontent>
<edge STYLE="sharp_bezier" COLOR="#006633" WIDTH="2"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_274601394">&#12494;&#12540;&#12488;</a>&#160;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;&#12513;&#12491;&#12517;&#12540;&#160;&#160;<a href="freeplane_ja.mm#ID_1365598976">&#32232;&#38598;&#160;&gt; &#12494;&#12540;&#12488;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="&#x96f2;" STYLE_REF="Reference" FOLDED="true" POSITION="right" ID="ID_1697684606" CREATED="1455910859994" MODIFIED="1455910859994" HGAP_QUANTITY="522.0 px" VSHIFT_QUANTITY="91.0 px">
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1697684606" STARTINCLINATION="-79;67;" ENDINCLINATION="-79;67;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; <b>&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i><b>&#65306;</b>&#160;<a href="freeplaneTutorial_ja.mm#ID_1150908697">&#38642;&#12395;&#12424;&#12427;&#12494;&#12540;&#12489;&#12464;&#12523;&#12540;&#12503;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;&#65306;</i><b>&#12513;&#12491;&#12517;&#12540;</b><i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_1759348470">&#26360;&#24335; &#160;&gt; &#38642;&#12398;&#12503;&#12525;&#12497;&#12486;&#12451;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<node TEXT="&#x77e9;&#x3000;&#x5f62;" ID="ID_1198357672" CREATED="1455910859994" MODIFIED="1455910859994" HGAP_QUANTITY="48.0 px" VSHIFT_QUANTITY="4.0 px">
<cloud COLOR="#f0f0f0" SHAPE="RECT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; <b>&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i><b>&#65306;</b>&#160;<a href="freeplaneTutorial_ja.mm#ID_1150908697">&#38642;&#22258;&#12356;&#12494;&#12540;&#12489;&#12464;&#12523;&#12540;&#12503;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplane_ja.mm#ID_759607649">&#26360;&#24335;&#160;&#160;&gt; &#38642;&#12434;&#20184;&#21152; or &#24418;&#12434;&#22793;&#26356;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="&#x30c8;&#x30b2;&#x30c8;&#x30b2;" ID="ID_1434127019" CREATED="1455910859994" MODIFIED="1455910859994">
<cloud COLOR="#f0f0f0" SHAPE="STAR"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; <b>&#160;&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i><b>&#65306;</b>&#160;<a href="freeplaneTutorial_ja.mm#ID_1150908697">&#38642;&#22258;&#12356;&#12494;&#12540;&#12489;&#12464;&#12523;&#12540;&#12503;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplane_ja.mm#ID_759607649">&#26360;&#24335;&#160;&#160;&gt; &#38642;&#12434;&#20184;&#21152; or &#24418;&#12434;&#22793;&#26356;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
</node>
<node TEXT="&#x95a2;&#x4fc2;&#x4ed8;&#x3051;" POSITION="right" ID="ID_441663322" CREATED="1455910859994" MODIFIED="1455910859994" STYLE="fork" HGAP_QUANTITY="-56.0 px" VSHIFT_QUANTITY="27.0 px"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <a href="freeplaneTutorial_ja.mm#ID_448981847">&#160;xx</a>&#160;
    </p>
  </body>
</html>
</richcontent>
<cloud COLOR="#f0f0f0" SHAPE="ARC"/>
<hook NAME="AlwaysUnfoldedNode"/>
<node TEXT="&#x30ce;&#x30fc;&#x30c9; a &#x306e;&#x4e0a;" ID="ID_1863548649" CREATED="1455910859994" MODIFIED="1455910859994" HGAP_QUANTITY="37.0 px" VSHIFT_QUANTITY="-13.0 px" STYLE="bubble"/>
<node TEXT="&#x30ce;&#x30fc;&#x30c9; a" ID="ID_1119041406" CREATED="1455910859994" MODIFIED="1455910859994" STYLE="bubble" HGAP_QUANTITY="53.0 px" VSHIFT_QUANTITY="7.0 px">
<arrowlink SHAPE="CUBIC_CURVE" COLOR="#ff0000" WIDTH="5" TRANSPARENCY="80" FONT_SIZE="8" FONT_FAMILY="SansSerif" DESTINATION="ID_268922755" SOURCE_LABEL="&#x89aa;&#x30ce;&#x30fc;&#x30c9;" TARGET_LABEL="&#x5b6b;&#x30ce;&#x30fc;&#x30c9;" MIDDLE_LABEL="&#x30ce;&#x30fc;&#x30c9;&#x306e;&#x968e;&#x5c64;" STARTINCLINATION="-2;23;" ENDINCLINATION="-21;59;" STARTARROW="NONE" ENDARROW="NONE"/>
<node TEXT="&#x30ce;&#x30fc;&#x30c9; b" ID="ID_1908863616" CREATED="1455910859995" MODIFIED="1455910859995" VGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="10.0 px" STYLE="bubble">
<edge STYLE="bezier" WIDTH="thin"/>
<node ID="ID_1947425814" CREATED="1455910859995" MODIFIED="1455910859995" HGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="-46.0 px" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12484;&#12540;&#12523;&#12481;&#12483;&#12503; </b>
    </p>
    <p>
      <b>&#34920;&#31034;&#21487;&#33021;</b>&#12398;&#21360;
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1947425814" STARTINCLINATION="13;34;" ENDINCLINATION="13;34;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<edge STYLE="hide_edge"/>
<hook NAME="FreeNode"/>
</node>
<node ID="ID_1143366438" CREATED="1455910859995" MODIFIED="1455910859995" HGAP_QUANTITY="110.0 px" VSHIFT_QUANTITY="-16.0 px" BACKGROUND_COLOR="#ffff99">
<icon BUILTIN="yes"/>
<richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#25240;&#12426;&#30067;&#12415;&#20013;</b>&#12398;&#21360;
    </p>
  </body>
</html>

</richcontent>
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1143366438" STARTINCLINATION="-41;22;" ENDINCLINATION="-41;22;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<font BOLD="false"/>
<edge STYLE="hide_edge"/>
<hook NAME="FreeNode"/>
</node>
<node TEXT="&#x30ce;&#x30fc;&#x30c9; c" ID="ID_268922755" CREATED="1455910859995" MODIFIED="1455910859995" VGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true" STYLE="bubble"><richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#12371;&#12398;&#12486;&#12461;&#12473;&#12488;&#12399;&#12289;
    </p>
    <p>
      <b>&#12484;&#12540;&#12523;&#12481;&#12483;&#12503;</b>&#12395;&#12375;
    </p>
    <p>
      &#12363;&#34920;&#31034;&#12373;&#12428;&#12414;&#12379;&#12435;&#12290;
    </p>
  </body>
</html>
</richcontent>
<node TEXT="etc." ID="ID_1829616131" CREATED="1455910859995" MODIFIED="1455910859995"/>
</node>
<node TEXT="&#x30b3;&#x30cd;&#x30af;&#x30bf;&#xa;(&#xff12;&#x30ce;&#x30fc;&#x30c9;&#x9593;)" STYLE_REF="Reference" ID="ID_389809087" CREATED="1455910859995" MODIFIED="1455910859995" HGAP_QUANTITY="140.0 px" VSHIFT_QUANTITY="79.0 px">
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_389809087" STARTINCLINATION="-65;-27;" ENDINCLINATION="-65;-27;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; <b>&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_1073407528">&#12467;&#12493;&#12463;&#12479;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;</b>&#12540;<i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_1803275985">&#32232;&#38598;&#160;&gt; &#12467;&#12493;&#12463;&#12479;&#12434;&#20184;&#21152;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
<font BOLD="false"/>
</node>
<node TEXT="&#x30e9;&#x30d9;&#x30eb;" STYLE_REF="Reference" ID="ID_1560136360" CREATED="1455910859995" MODIFIED="1455910859995" HGAP_QUANTITY="0.0 px" VSHIFT_QUANTITY="99.0 px">
<arrowlink SHAPE="LINE" COLOR="#0033cc" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1560136360" STARTINCLINATION="-4;-35;" ENDINCLINATION="-4;-35;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; <b>&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_1073407528">&#12467;&#12493;&#12463;&#12479;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;</b>&#12540;<i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_1803275985">&#32232;&#38598;&#160;&gt; &#12467;&#12493;&#12463;&#12479;&#12434;&#20184;&#21152;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<hook NAME="FreeNode"/>
</node>
</node>
</node>
<node TEXT="&#x30ce;&#x30fc;&#x30c9; a &#x306e;&#x4e0b;" ID="ID_975219834" CREATED="1455910859996" MODIFIED="1455910859996" HGAP_QUANTITY="27.0 px" VSHIFT_QUANTITY="34.0 px" STYLE="bubble"/>
</node>
<node TEXT="&#x30b3;&#x30cd;&#x30af;&#x30bf;&#xa;(&#x76f8;&#x65b9;&#x30ce;&#x30fc;&#x30c9;&#x7121;&#x3057;)" STYLE_REF="Reference" POSITION="right" ID="ID_1828022839" CREATED="1455910859996" MODIFIED="1455910859996" HGAP_QUANTITY="541.0 px" VSHIFT_QUANTITY="183.0 px">
<arrowlink SHAPE="LINE" COLOR="#000000" WIDTH="2" TRANSPARENCY="80" DASH="3 3" FONT_SIZE="12" FONT_FAMILY="SansSerif" DESTINATION="ID_1828022839" STARTINCLINATION="-71;-52;" ENDINCLINATION="-71;-52;" STARTARROW="NONE" ENDARROW="DEFAULT"/>
<hook NAME="FreeNode"/>
<font BOLD="false"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; <b>&#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;</b>&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_1073407528">&#12467;&#12493;&#12463;&#12479;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;</b>&#12540;<i>&#160;</i>&#160;<a href="freeplane_ja.mm#ID_1803275985">&#32232;&#38598;&#160;&gt; &#12467;&#12493;&#12463;&#12479;&#12434;&#20184;&#21152;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node TEXT="&#x30ce;&#x30fc;&#x30c9;&#x30b3;&#x30a2;&#x306e;&#x66f8;&#x5f0f;&#x8a2d;&#x5b9a;" FOLDED="true" POSITION="left" ID="ID_1983670807" CREATED="1455910859996" MODIFIED="1455910859996" HGAP_QUANTITY="10.0 px" VSHIFT_QUANTITY="49.0 px" TEXT_SHORTENED="true"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503;&#160;&gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_1778719162">&#26360;&#24335;&#12392;&#12473;&#12479;&#12452;&#12523;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplane_ja.mm#ID_39827582">&#26360;&#24335;&#160;&gt; &#12494;&#12540;&#12489;&#12467;&#12450;&#38306;&#20418;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<node ID="ID_549836127" CREATED="1455910859996" MODIFIED="1455910859996" STYLE="bubble" VSHIFT_QUANTITY="110.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#22258;&#12415;</b>&#34920;&#31034;&#12398;&#12494;&#12540;&#12489;&#12467;&#12450;
    </p>
  </body>
</html>

</richcontent>
</node>
<node TEXT="&#x8272;" ID="ID_803864072" CREATED="1455910859996" MODIFIED="1455910859996">
<node TEXT="&#x30ce;&#x30fc;&#x30c9;&#x306e;&#x6587;&#x5b57;&#x8272;" ID="ID_1110939341" CREATED="1455910859996" MODIFIED="1455910859996" COLOR="#ff0066"/>
<node TEXT="&#x30ce;&#x30fc;&#x30c9;&#x306e;&#x80cc;&#x666f;&#x8272;" ID="ID_1683102097" CREATED="1455910859996" MODIFIED="1455910859996" BACKGROUND_COLOR="#00ff00"/>
<node TEXT="&#x30de;&#x30c3;&#x30d7;&#x306e;&#x80cc;&#x666f;&#x8272;" ID="ID_650309977" CREATED="1455910859996" MODIFIED="1455910859996"/>
</node>
<node TEXT="&#x30d5;&#x30a9;&#x30f3;&#x30c8;" ID="ID_609278590" CREATED="1455910859996" MODIFIED="1455910859996">
<font NAME="SansSerif" SIZE="12"/>
<node TEXT="Times New Roman" ID="ID_634001381" CREATED="1455910859996" MODIFIED="1455910859996">
<font NAME="Times New Roman" SIZE="16"/>
</node>
<node TEXT="Verdana" ID="ID_595317478" CREATED="1455910859996" MODIFIED="1455910859996">
<font NAME="Verdana" SIZE="12"/>
</node>
<node TEXT="Dialog font" ID="ID_365055995" CREATED="1455910859996" MODIFIED="1455910859996">
<font NAME="Dialog" SIZE="21"/>
</node>
</node>
<node TEXT="&#x70b9;&#x6ec5;" ID="ID_381735248" CREATED="1455910859997" MODIFIED="1455910859997" VSHIFT_QUANTITY="-13.0 px">
<hook NAME="accessories/plugins/BlinkingNodeHook.properties"/>
</node>
</node>
<node TEXT="" POSITION="left" ID="ID_288630513" CREATED="1455910860001" MODIFIED="1455910860001">
<hook NAME="FirstGroupNode"/>
</node>
<node TEXT="&#x7279;&#x6b8a;&#x6a5f;&#x80fd;" POSITION="left" ID="ID_206364326" CREATED="1455910859997" MODIFIED="1455910859997" VSHIFT_QUANTITY="20.0 px">
<node ENCRYPTED_CONTENT="t/NS/HPSppU= VbQIDGWIdFE=" ID="ID_36040841" CREATED="1455910859997" MODIFIED="1455910859997" TEXT_SHORTENED="true" HGAP_QUANTITY="30.0 px"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#12497;&#12473;&#12527;&#12540;&#12489;&#12434;&#20351;&#12387;&#12383;<b>&#12487;&#12540;&#12479;&#20445;&#35703;</b>
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_1232153769">&#12494;&#12540;&#12489;&#12434;&#20445;&#35703;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b>&#160;<a href="freeplane_ja.mm#ID_83654353">&#12484;&#12540;&#12523;&#160;&gt;&#12497;&#12473;&#12527;&#12540;&#12489;&#12391;&#20445;&#35703;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node ID="ID_49859005" CREATED="1455910859998" MODIFIED="1455910859998" HGAP_QUANTITY="30.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#35336;&#31639;</b>&#160;=3+4
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_448338872">&#35336;&#31639;&#12434;&#23455;&#34892;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;Wiki&#160;<a href="freeplane_ja.mm#ID_1130453106">&#35336;&#31639;&#12434;&#23455;&#34892;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<node TEXT="=3 + 4" ID="ID_38981929" CREATED="1455910859998" MODIFIED="1455910859998" TEXT_SHORTENED="true"><richcontent TYPE="DETAILS">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#12510;&#12483;&#12503;&#38322;&#35239;&#12514;&#12540;&#12489;
    </p>
    <p>
      &#12391;&#12399;&#12289;&#35336;&#31639;&#32080;&#26524;&#12399;
    </p>
    <p>
      &#34920;&#31034;&#12373;&#12428;&#12414;&#12379;&#12435;&#12290;
    </p>
  </body>
</html>
</richcontent>
</node>
</node>
<node ID="ID_1885496887" CREATED="1455910859998" MODIFIED="1455910859998" HGAP_QUANTITY="31.0 px" VSHIFT_QUANTITY="10.0 px" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      &#12522;&#12510;&#12452;&#12531;&#12480;&#65288;<b>&#12459;&#12524;&#12531;&#12480;</b>&#65289;
    </p>
  </body>
</html>

</richcontent>
<hook NAME="plugins/TimeManagementReminder.xml">
    <Parameters REMINDUSERAT="2077460580480" PERIOD="1" UNIT="DAY"/>
</hook>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_1959496513">&#26085;&#20184;&#12539;&#26178;&#21051;&#38306;&#36899;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b>&#160;<a href="freeplane_ja.mm#ID_1959496513">&#12484;&#12540;&#12523;&#160;&gt; &#26178;&#38291;&#31649;&#29702;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
</node>
<node TEXT="&#x305d;&#x306e;&#x4ed6;&#x306e;&#x6a5f;&#x80fd;" POSITION="left" ID="ID_454770946" CREATED="1455910859999" MODIFIED="1455910859999" VSHIFT_QUANTITY="30.0 px">
<node ID="ID_1987204825" CREATED="1455910859999" MODIFIED="1455910859999" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12501;&#12451;&#12523;&#12479;</b>&#12392;<b>&#20006;&#12409;&#26367;&#12360;</b>
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_828862571">&#12494;&#12540;&#12489;&#12398;&#12501;&#12451;&#12523;&#12479;&#12392;&#26908;&#32034;</a>&#12290;<a href="freeplaneTutorial_ja.mm#ID_1014457432">&#20006;&#12409;&#26367;&#12360;</a>&#160;&#12395;&#12418;&#30041;&#24847;&#12290;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b>&#160;<a href="freeplane_ja.mm#ID_1254354349">&#12501;&#12451;&#12523;&#12479;</a>&#160;&#12290;<a href="freeplane_ja.mm#ID_1942706169">&#32232;&#38598;&#160;&gt; &#31227;&#21205;&#12392;&#20006;&#12409;&#26367;&#12360;</a>&#160;&#12395;&#12418;&#30041;&#24847;&#12290;
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal"/>
</node>
<node ID="ID_1603681371" CREATED="1455910859999" MODIFIED="1455910859999" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12486;&#12531;&#12503;&#12524;&#12540;&#12488;</b>&#12392;<b>&#12473;&#12479;&#12452;&#12523;</b>
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_1268042238">&#12486;&#12531;&#12503;&#12524;&#12540;&#12488;&#22411;&#24773;&#22577;</a>&#12290;<a href="freeplaneTutorial_ja.mm#ID_1838680824">&#12473;&#12479;&#12452;&#12523;</a><b>&#160;</b>&#12395;&#30041;&#24847;&#12290;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b><a href="freeplane_ja.mm#ID_258919699">&#26360;&#24335;</a>&#160;&#12290;<a href="freeplane_ja.mm#ID_1796388799">&#12486;&#12531;&#12503;&#12524;&#12540;&#12488;</a><b>&#160;</b>&#12395;&#30041;&#24847;&#12290;
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal"/>
</node>
<node TEXT="&#x30de;&#x30c3;&#x30d7;&#x306e;&#x516c;&#x958b;&#x3068;&#x30b7;&#x30a7;&#x30a2;" ID="ID_671406309" CREATED="1455910859999" MODIFIED="1455910859999"><richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;<i><a href="freeplaneTutorial_ja.mm#ID_1613405030">7. &#12510;&#12483;&#12503;&#12398;&#20844;&#34920;&#12392;&#12471;&#12455;&#12450;</a></i>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplane_ja.mm#ID_1111281504">&#30011;&#20687;&#12398;&#20844;&#34920;</a>&#160;&#12290;<a href="freeplane_ja.mm#ID_126764093">&#12454;&#12455;&#12502;&#19978;&#12391;&#12398;&#20844;&#34920;&#12420;&#12471;&#12455;&#12450;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
</node>
<node ID="ID_1058310897" CREATED="1455910860000" MODIFIED="1455910860000" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12473;&#12463;&#12522;&#12503;&#12488;</b>&#12392;<b>&#12450;&#12489;&#12458;&#12531;</b>
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;&#160;<a href="freeplaneTutorial_ja.mm#ID_519455593">&#12473;&#12463;&#12522;&#12503;&#12488;&#12398;&#20316;&#25104;&#12392;&#20351;&#29992;</a>&#12290;<a href="freeplaneTutorial_ja.mm#ID_1156954596">&#12450;&#12489;&#12458;&#12531;</a>&#160;&#12395;&#12418;&#30041;&#24847;&#12290;
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<b>&#12513;&#12491;&#12517;&#12540;</b>&#160;<a href="freeplane_ja.mm#ID_1890181858">&#12484;&#12540;&#12523;&#160;&gt; &#12473;&#12463;&#12522;&#12503;&#12488;</a>&#160;&#12290;<a href="freeplane_ja.mm#ID_100406395">&#12484;&#12540;&#12523;&#160;&gt; &#12450;&#12489;&#12458;&#12531;</a>&#160;&#12395;&#12418;&#30041;&#24847;&#12290;
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal"/>
</node>
<node ID="ID_739070756" CREATED="1455910860000" MODIFIED="1455910860000" TEXT_SHORTENED="true"><richcontent TYPE="NODE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#12473;&#12506;&#12523;&#12481;&#12455;&#12483;&#12463;</b>&#12392;&#12450;&#12459;&#12487;&#12511;&#12483;&#12463;
    </p>
    <p>
      &#12521;&#12452;&#12486;&#12451;&#12531;&#12464;&#12539;&#12497;&#12483;&#12465;&#12540;&#12472;
    </p>
  </body>
</html>

</richcontent>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;<a href="freeplaneTutorial_ja.mm#ID_141336344">&#12473;&#12506;&#12523;&#12481;&#12455;&#12483;&#12463;&#29992;&#36766;&#26360;</a>&#12290;<a href="freeplaneTutorial_ja.mm#ID_170927482">A&#31185;&#23398;&#35542;&#25991;&#22519;&#31558;&#12497;&#12483;&#12465;&#12540;&#12472;</a>&#160;&#12395;&#12418;&#30041;&#24847;&#12290;
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge STYLE="horizontal"/>
</node>
</node>
<node TEXT="" POSITION="left" ID="ID_1396107803" CREATED="1455910860005" MODIFIED="1455910860005">
<hook NAME="SummaryNode"/>
<node TEXT="&#x307e;&#x3068;&#x3081;&#x30ce;&#x30fc;&#x30c9;&#xa;&#xff08;&#x6ce2;&#x62ec;&#x5f27;)" ID="ID_499898058" CREATED="1455910860000" MODIFIED="1455910860000" HGAP_QUANTITY="40.0 px">
<font BOLD="true"/>
<richcontent TYPE="NOTE">

<html>
  <head>
    
  </head>
  <body>
    <p>
      <b>&#21442;&#12288;&#29031;</b>
    </p>
    <ul>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12481;&#12517;&#12540;&#12488;&#12522;&#12450;&#12523;&#12301;</i>&#65306;<a href="http://freeplaneTutorial_ja.mm#ID_651594550">&#12414;&#12392;&#12417;&#12494;&#12540;&#12489;&#12464;&#12523;&#12540;&#12503;</a>
      </li>
      <li>
        <i>&#12300;&#12504;&#12523;&#12503; &gt; &#12510;&#12491;&#12517;&#12450;&#12523;&#12301;</i>&#65306;<a href="http://freeplane_ja.mm#ID_1700918771">&#32232;&#38598;&#160;&gt; &#12494;&#12540;&#12489;&#12464;&#12523;&#12540;&#12503;&#160;&gt; &#26032;&#35215;&#12414;&#12392;&#12417;&#12494;&#12540;&#12489;(&#36984;&#25246;&#12494;&#12540;&#12489;&#32676;</a>
      </li>
    </ul>
  </body>
</html>
</richcontent>
<edge COLOR="#ff00ff" WIDTH="3"/>
</node>
</node>
</node>
</map>
